function [pM,omega] = gurson(P,T,p0,p_max,mat,matrixstrain)

% Declaring the material parameters
s0=mat(1); Q1=mat(2); C1=mat(3); Q2=mat(4); C2=mat(5);
Q3=0; C3=0;

 % Creating a strain resolution and a corresponding plastic 
 % strain vector within the increment
 dp=(p_max-p0)/100;
 p=p0:dp:p_max;
 
 % Puts the values from last increment as the initial values for this
 % iteration
 pM(1)=matrixstrain; 
 omega(1)=P(3); 
 
  for i=1:length(p)
   s_M(i)=s0+Q1*(1-exp(-C1*pM(i)))...
            +Q2*(1-exp(-C2*pM(i)))...
            +Q3*(1-exp(-C3*pM(i)));
   s_eq(i)=s_M(i);
   
   % Using the Newton-Raphson method to solve
   % the equation Yieldfunction=0 for s_e according to eq. C1
   Yieldfunction=1;
    while abs(Yieldfunction)>10^-6
     Yieldfunction=(s_eq(i)/s_M(i))^2+...
       2*P(1)*omega(i)*cosh(3*P(2)*T/2*s_eq(i)/s_M(i))...
       -1-(omega(i)*P(1))^2;
     dYieldfunction=2*s_eq(i)/s_M(i)^2+...
         P(1)*omega(i)*3*P(2)*T/(s_M(i))...
         *sinh(3*P(2)*T/2*s_eq(i)/s_M(i));
     s_eq(i)=s_eq(i)-Yieldfunction/dYieldfunction;
    end
    
    % Calculating the incremental plastic parameter according to eq C2
    dLambda(i)=s_eq(i)*dp/(2*(s_eq(i)/s_M(i))^2+...
        3*omega(i)*P(1)*P(2)*T*s_eq(i)/s_M(i)...
        *sinh(3*P(2)*T/2*s_eq(i)/s_M(i)));
    
    % Calculate the microcopic strain according to C3
    pM(i+1)=pM(i)+s_eq(i)*dp/((1-omega(i))*s_M(i));
    
    % calculate void volume fraction according to C4
    omega(i+1)=omega(i)+(1-omega(i))*dLambda(i)...
               *3*omega(i)*P(1)*P(2)/s_M(i)*...
               sinh(3*P(2)*T/2*s_eq(i)/s_M(i));
  end
end